btrdb.transformers
=========================

A number of tranformation and serialization functions have been developed so
you can use the data in the format of your choice.  These functions are provided
in the :code:`btrdb.utils.transformers` module but are also available directly
off the the :code:`StreamSet` class.

.. automodule:: btrdb.transformers

.. autofunction:: to_dict

.. autofunction:: to_array

.. autofunction:: to_series

.. autofunction:: to_dataframe

.. autofunction:: to_csv
